# Changelog

## [Unreleased](https://github.com/firefly-cpp/AST-Monitor/tree/HEAD)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.4.2...HEAD)

**Closed issues:**

- tcx2gpx problem [\#61](https://github.com/firefly-cpp/AST-Monitor/issues/61)

**Merged pull requests:**

- Bump urllib3 from 2.0.6 to 2.0.7 [\#66](https://github.com/firefly-cpp/AST-Monitor/pull/66) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump postcss from 8.4.28 to 8.4.31 in /ast\_monitor/map [\#65](https://github.com/firefly-cpp/AST-Monitor/pull/65) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump urllib3 from 2.0.5 to 2.0.6 [\#64](https://github.com/firefly-cpp/AST-Monitor/pull/64) ([dependabot[bot]](https://github.com/apps/dependabot))
- Update workflow [\#63](https://github.com/firefly-cpp/AST-Monitor/pull/63) ([KukovecRok](https://github.com/KukovecRok))

## [0.4.2](https://github.com/firefly-cpp/AST-Monitor/tree/0.4.2) (2023-10-02)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.4.1...0.4.2)

**Closed issues:**

- Switch to pyqt6 [\#46](https://github.com/firefly-cpp/AST-Monitor/issues/46)
- Upload activity [\#20](https://github.com/firefly-cpp/AST-Monitor/issues/20)
- Add real time visualization [\#15](https://github.com/firefly-cpp/AST-Monitor/issues/15)

**Merged pull requests:**

- Fixed route reader, code docs update [\#62](https://github.com/firefly-cpp/AST-Monitor/pull/62) ([alenrajsp](https://github.com/alenrajsp))
- AST Monitor update [\#60](https://github.com/firefly-cpp/AST-Monitor/pull/60) ([alenrajsp](https://github.com/alenrajsp))
- docs: add alenrajsp as a contributor for maintenance, and bug [\#58](https://github.com/firefly-cpp/AST-Monitor/pull/58) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- docs: add rhododendrom as a contributor for design [\#57](https://github.com/firefly-cpp/AST-Monitor/pull/57) ([allcontributors[bot]](https://github.com/apps/allcontributors))

## [0.4.1](https://github.com/firefly-cpp/AST-Monitor/tree/0.4.1) (2023-09-11)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.4.0...0.4.1)

**Closed issues:**

- Add simple logo [\#47](https://github.com/firefly-cpp/AST-Monitor/issues/47)

**Merged pull requests:**

- Bump certifi from 2023.5.7 to 2023.7.22 [\#56](https://github.com/firefly-cpp/AST-Monitor/pull/56) ([dependabot[bot]](https://github.com/apps/dependabot))
- Map visualizations update [\#55](https://github.com/firefly-cpp/AST-Monitor/pull/55) ([alenrajsp](https://github.com/alenrajsp))
- Update README.md [\#54](https://github.com/firefly-cpp/AST-Monitor/pull/54) ([alenrajsp](https://github.com/alenrajsp))
- add logo [\#53](https://github.com/firefly-cpp/AST-Monitor/pull/53) ([rhododendrom](https://github.com/rhododendrom))
- Bump aiohttp from 3.8.4 to 3.8.5 [\#52](https://github.com/firefly-cpp/AST-Monitor/pull/52) ([dependabot[bot]](https://github.com/apps/dependabot))
- docs: update README [\#51](https://github.com/firefly-cpp/AST-Monitor/pull/51) ([zala-lahovnik](https://github.com/zala-lahovnik))

## [0.4.0](https://github.com/firefly-cpp/AST-Monitor/tree/0.4.0) (2023-07-02)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.3.3...0.4.0)

**Merged pull requests:**

- docs: add alenrajsp as a contributor for code [\#50](https://github.com/firefly-cpp/AST-Monitor/pull/50) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- Updated to PyQt6 version + [\#49](https://github.com/firefly-cpp/AST-Monitor/pull/49) ([alenrajsp](https://github.com/alenrajsp))

## [0.3.3](https://github.com/firefly-cpp/AST-Monitor/tree/0.3.3) (2023-06-21)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.3.2...0.3.3)

**Closed issues:**

- Fix docs [\#44](https://github.com/firefly-cpp/AST-Monitor/issues/44)
- Openant dependency [\#42](https://github.com/firefly-cpp/AST-Monitor/issues/42)

**Merged pull requests:**

- docs: add KukovecRok as a contributor for doc, and bug [\#48](https://github.com/firefly-cpp/AST-Monitor/pull/48) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- Sphinx docs fix \#44 [\#45](https://github.com/firefly-cpp/AST-Monitor/pull/45) ([KukovecRok](https://github.com/KukovecRok))
- Bump requests from 2.30.0 to 2.31.0 [\#43](https://github.com/firefly-cpp/AST-Monitor/pull/43) ([dependabot[bot]](https://github.com/apps/dependabot))

## [0.3.2](https://github.com/firefly-cpp/AST-Monitor/tree/0.3.2) (2023-01-28)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.3.1...0.3.2)

**Closed issues:**

-  @all-contributors add [\#32](https://github.com/firefly-cpp/AST-Monitor/issues/32)

**Merged pull requests:**

- Include openant in dependency list \(finally available on pypi\) [\#41](https://github.com/firefly-cpp/AST-Monitor/pull/41) ([firefly-cpp](https://github.com/firefly-cpp))
- Bump certifi from 2022.9.24 to 2022.12.7 [\#40](https://github.com/firefly-cpp/AST-Monitor/pull/40) ([dependabot[bot]](https://github.com/apps/dependabot))
- docs: add alenrajsp as a contributor for content [\#39](https://github.com/firefly-cpp/AST-Monitor/pull/39) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- docs: add firefly-cpp as a contributor for platform [\#38](https://github.com/firefly-cpp/AST-Monitor/pull/38) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- docs: add carlosal1015 as a contributor for platform [\#37](https://github.com/firefly-cpp/AST-Monitor/pull/37) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- docs: add luckyLukac as a contributor for design [\#36](https://github.com/firefly-cpp/AST-Monitor/pull/36) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- docs: add firefly-cpp as a contributor for doc, code, and 2 more [\#35](https://github.com/firefly-cpp/AST-Monitor/pull/35) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- docs: add luckyLukac as a contributor for bug, doc, and code [\#34](https://github.com/firefly-cpp/AST-Monitor/pull/34) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- docs: add firefly-cpp as a contributor for bug [\#33](https://github.com/firefly-cpp/AST-Monitor/pull/33) ([allcontributors[bot]](https://github.com/apps/allcontributors))
- Bump pillow from 9.2.0 to 9.3.0 [\#31](https://github.com/firefly-cpp/AST-Monitor/pull/31) ([dependabot[bot]](https://github.com/apps/dependabot))

## [0.3.1](https://github.com/firefly-cpp/AST-Monitor/tree/0.3.1) (2022-09-15)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.3.0...0.3.1)

**Closed issues:**

- Path error [\#29](https://github.com/firefly-cpp/AST-Monitor/issues/29)
- Add a short outline/description of each figure in README [\#25](https://github.com/firefly-cpp/AST-Monitor/issues/25)

**Merged pull requests:**

- Small bugifx [\#30](https://github.com/firefly-cpp/AST-Monitor/pull/30) ([luckyLukac](https://github.com/luckyLukac))

## [0.3.0](https://github.com/firefly-cpp/AST-Monitor/tree/0.3.0) (2022-09-13)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.2.1...0.3.0)

**Closed issues:**

- Show various TRIMP values on the dashboard [\#21](https://github.com/firefly-cpp/AST-Monitor/issues/21)
- Add reference/minor documentation for ast-tdl [\#17](https://github.com/firefly-cpp/AST-Monitor/issues/17)

**Merged pull requests:**

- Complete revamp of the AST-Monitor application [\#28](https://github.com/firefly-cpp/AST-Monitor/pull/28) ([luckyLukac](https://github.com/luckyLukac))
- Update lock file [\#27](https://github.com/firefly-cpp/AST-Monitor/pull/27) ([firefly-cpp](https://github.com/firefly-cpp))
- Add instructions for install from AUR [\#26](https://github.com/firefly-cpp/AST-Monitor/pull/26) ([carlosal1015](https://github.com/carlosal1015))

## [0.2.1](https://github.com/firefly-cpp/AST-Monitor/tree/0.2.1) (2022-07-22)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.2.0...0.2.1)

**Merged pull requests:**

- Slight digital twin algorithm and GUI improvements [\#24](https://github.com/firefly-cpp/AST-Monitor/pull/24) ([luckyLukac](https://github.com/luckyLukac))
- Digital twin improvements [\#23](https://github.com/firefly-cpp/AST-Monitor/pull/23) ([luckyLukac](https://github.com/luckyLukac))

## [0.2.0](https://github.com/firefly-cpp/AST-Monitor/tree/0.2.0) (2022-07-12)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.5...0.2.0)

**Closed issues:**

- Generate tcx/gpx file from sensor data [\#5](https://github.com/firefly-cpp/AST-Monitor/issues/5)

**Merged pull requests:**

- Digital twin implementation [\#22](https://github.com/firefly-cpp/AST-Monitor/pull/22) ([luckyLukac](https://github.com/luckyLukac))
- Interval data depiction [\#19](https://github.com/firefly-cpp/AST-Monitor/pull/19) ([luckyLukac](https://github.com/luckyLukac))

## [0.1.5](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.5) (2022-06-24)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.4...0.1.5)

**Merged pull requests:**

- Minor Flake8 changes [\#18](https://github.com/firefly-cpp/AST-Monitor/pull/18) ([luckyLukac](https://github.com/luckyLukac))
- Training loading and unit tests fix [\#16](https://github.com/firefly-cpp/AST-Monitor/pull/16) ([luckyLukac](https://github.com/luckyLukac))

## [0.1.4](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.4) (2022-06-07)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.3...0.1.4)

**Closed issues:**

- Screenshot of GUI [\#11](https://github.com/firefly-cpp/AST-Monitor/issues/11)

**Merged pull requests:**

- Update README.md [\#14](https://github.com/firefly-cpp/AST-Monitor/pull/14) ([luckyLukac](https://github.com/luckyLukac))
- Map addition [\#13](https://github.com/firefly-cpp/AST-Monitor/pull/13) ([luckyLukac](https://github.com/luckyLukac))
- GUI and code improvements [\#12](https://github.com/firefly-cpp/AST-Monitor/pull/12) ([luckyLukac](https://github.com/luckyLukac))

## [0.1.3](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.3) (2022-05-03)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.2...0.1.3)

**Merged pull requests:**

- GUI enhancements [\#10](https://github.com/firefly-cpp/AST-Monitor/pull/10) ([luckyLukac](https://github.com/luckyLukac))
- Redesigned GUI [\#9](https://github.com/firefly-cpp/AST-Monitor/pull/9) ([luckyLukac](https://github.com/luckyLukac))
- Update README.md [\#6](https://github.com/firefly-cpp/AST-Monitor/pull/6) ([alenrajsp](https://github.com/alenrajsp))

## [0.1.2](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.2) (2022-03-10)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.1...0.1.2)

**Closed issues:**

- 'ant' module cannot be installed using PIP [\#1](https://github.com/firefly-cpp/AST-Monitor/issues/1)

**Merged pull requests:**

- Small changes in GUI [\#4](https://github.com/firefly-cpp/AST-Monitor/pull/4) ([luckyLukac](https://github.com/luckyLukac))
- Code refactored to comply with Flake standards [\#3](https://github.com/firefly-cpp/AST-Monitor/pull/3) ([luckyLukac](https://github.com/luckyLukac))
- Small bugfix at pyqt-feedback-flow usage [\#2](https://github.com/firefly-cpp/AST-Monitor/pull/2) ([luckyLukac](https://github.com/luckyLukac))

## [0.1.1](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.1) (2022-01-25)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/c3527a1296385a84a0b0be4df0e1609527cbac67...0.1.1)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
